Logo Partas.TypeProvider

Partas.TypeProvider.BuildHelper Namespace

Type Description

BuildHelperProvider (Type)

TypeProvider for build scripts and projects, providing compile-time literals, hints, and scaffolding for common tasks.

The BuildHelperProvider provides several distinct providers which are optional, but share a common feature of being defined at the root of a repository.

BuildHelperProvider (Type)

TypeProvider for build scripts and projects, providing compile-time literals, hints, and scaffolding for common tasks.

The BuildHelperProvider provides several distinct providers which are optional, but share a common feature of being defined at the root of a repository.

Type something to start searching.